==> proustr_0.2.0.tar.gz: proustr/R/proust_novels.R <==
#' Marcel Proust's novel "Du côté de chez Swann"
#'
#' A dataset containing Marcel Proust's "Du côté de chez Swann". 
#' This text has been downloaded from WikiSource.
#'
#' @source \url{https://fr.wikisource.org/wiki/Du_c%C3%B4t%C3%A9_de_chez_Swann}
#'
#' @format A tibble with text, book, volume, and year
"ducotedechezswann"

#' Marcel Proust's novel "À l’ombre des jeunes filles en fleurs"
#'
#' A dataset containing Marcel Proust's "À l’ombre des jeunes filles en fleurs". 
#' This text has been downloaded from WikiSource.
#'
#' @source \url{https://fr.wikisource.org/wiki/%C3%80_l%E2%80%99ombre_des_jeunes_filles_en_fleurs}
#'
#' @format A tibble with text, book, volume, and year
"alombredesjeunesfillesenfleurs"

#' Marcel Proust's novel "Le côté de Guermantes"
#'
#' A dataset containing Marcel Proust's "À l’ombre des jeunes filles en fleurs". 
#' This text has been downloaded from WikiSource.
#'
#' @source \url{https://fr.wikisource.org/wiki/Le_C%C3%B4t%C3%A9_de_Guermantes}
#'
#' @format A tibble with text, book, volume, and year
"lecotedeguermantes"

#' Marcel Proust's novel "Sodome et Gomorrhe"
#'
#' A dataset containing Marcel Proust's "Sodom et Gomorrhe". 
#' This text has been downloaded from WikiSource.
#'
#' @source \url{https://fr.wikisource.org/wiki/Sodome_et_Gomorrhe}
#'
#' @format A tibble with text, book, volume, and year
"sodomeetgomorrhe"

#' Marcel Proust's novel "La Prisonnière"
#'
#' A dataset containing Marcel Proust's "La prisonnière". 
#' This text has been downloaded from WikiSource.
#'
#' @source \url{https://fr.wikisource.org/wiki/La_Prisonni%C3%A8re}
#'
#' @format A tibble with text, book, volume, and year
"laprisonniere"

#' Marcel Proust's novel "Albertine disparue"
#'
#' A dataset containing Marcel Proust's "Albertine disparue". 
#' This text has been downloaded from WikiSource.
#'
#' @source \url{https://fr.wikisource.org/wiki/Albertine_disparue}
#'
#' @format A tibble with text, book, volume, and year
"albertinedisparue"

#' Marcel Proust's novel "Le temps retrouvé"
#'
#' A dataset containing Marcel Proust's "Le temps retrouvé". 
#' This text has been downloaded from WikiSource.
#'
#' @source \url{https://fr.wikisource.org/wiki/Le_Temps_retrouv%C3%A9}
#'
#' @format A tibble with text, book, volume, and year.
"letempretrouve"

==> proustr_0.4.0.tar.gz: proustr/R/proust_novels.R <==
#' Marcel Proust's novel "Du côté de chez Swann"
#'
#' A dataset containing Marcel Proust's "Du côté de chez Swann". 
#' This text has been downloaded from WikiSource.
#'
#' @source <https://fr.wikisource.org/wiki/Du_c%C3%B4t%C3%A9_de_chez_Swann>
#' @format A tibble with text, book, volume, and year
"ducotedechezswann"

#' Marcel Proust's novel "À l’ombre des jeunes filles en fleurs"
#'
#' A dataset containing Marcel Proust's "À l’ombre des jeunes filles en fleurs". 
#' This text has been downloaded from WikiSource.
#'
#' @source <https://fr.wikisource.org/wiki/%C3%80_l%E2%80%99ombre_des_jeunes_filles_en_fleurs>
#' @format A tibble with text, book, volume, and year
"alombredesjeunesfillesenfleurs"

#' Marcel Proust's novel "Le côté de Guermantes"
#'
#' A dataset containing Marcel Proust's "À l’ombre des jeunes filles en fleurs". 
#' This text has been downloaded from WikiSource.
#'
#' @source <https://fr.wikisource.org/wiki/Le_C%C3%B4t%C3%A9_de_Guermantes>
#'
#' @format A tibble with text, book, volume, and year
"lecotedeguermantes"

#' Marcel Proust's novel "Sodome et Gomorrhe"
#'
#' A dataset containing Marcel Proust's "Sodom et Gomorrhe". 
#' This text has been downloaded from WikiSource.
#'
#' @source <https://fr.wikisource.org/wiki/Sodome_et_Gomorrhe>
#'
#' @format A tibble with text, book, volume, and year
"sodomeetgomorrhe"

#' Marcel Proust's novel "La Prisonnière"
#'
#' A dataset containing Marcel Proust's "La prisonnière". 
#' This text has been downloaded from WikiSource.
#'
#' @source <https://fr.wikisource.org/wiki/La_Prisonni%C3%A8re>
#'
#' @format A tibble with text, book, volume, and year
"laprisonniere"

#' Marcel Proust's novel "Albertine disparue"
#'
#' A dataset containing Marcel Proust's "Albertine disparue". 
#' This text has been downloaded from WikiSource.
#'
#' @source <https://fr.wikisource.org/wiki/Albertine_disparue>
#'
#' @format A tibble with text, book, volume, and year
"albertinedisparue"

#' Marcel Proust's novel "Le temps retrouvé"
#'
#' A dataset containing Marcel Proust's "Le temps retrouvé". 
#' This text has been downloaded from WikiSource.
#'
#' @source <https://fr.wikisource.org/wiki/Le_Temps_retrouv%C3%A9>
#'
#' @format A tibble with text, book, volume, and year.
"letempretrouve"
